Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/npm/cli.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKat Marchán <kzm@zkat.tech>2018-08-22 20:38:40 +0300
committerKat Marchán <kzm@zkat.tech>2018-08-22 20:38:40 +0300
commit30bc9900ae79c80bf0bdee0ae6372da6f668124c (patch)
tree0341200107465e016f310bc8441702ba6229676b /node_modules/ci-info
parent1bc5b8ceabc86bfe4777732f25ffef0f3de81bd1 (diff)
ci-info@1.4.0
Adds support for two more CI services Credit: @watson
Diffstat (limited to 'node_modules/ci-info')
-rw-r--r--node_modules/ci-info/CHANGELOG.md45
-rw-r--r--node_modules/ci-info/README.md8
-rw-r--r--node_modules/ci-info/index.js11
-rw-r--r--node_modules/ci-info/package.json34
4 files changed, 76 insertions, 22 deletions
diff --git a/node_modules/ci-info/CHANGELOG.md b/node_modules/ci-info/CHANGELOG.md
new file mode 100644
index 000000000..0e9f54229
--- /dev/null
+++ b/node_modules/ci-info/CHANGELOG.md
@@ -0,0 +1,45 @@
+# Changelog
+
+## v1.4.0
+
+* feat: add Cirrus CI detection ([#13](https://github.com/watson/ci-info/pull/13))
+* feat: add Shippable CI detection ([#14](https://github.com/watson/ci-info/pull/14))
+
+## v1.3.1
+
+* chore: reduce npm package size by not including `.github` folder content ([#11](https://github.com/watson/ci-info/pull/11))
+
+## v1.3.0
+
+* feat: add support for Strider CD
+* chore: deprecate vendor constant `TDDIUM` in favor of `SOLANO`
+* docs: add missing vendor constant to docs
+
+## v1.2.0
+
+* feat: detect solano-ci ([#9](https://github.com/watson/ci-info/pull/9))
+
+## v1.1.3
+
+* fix: fix spelling of Hunson in `ci.name`
+
+## v1.1.2
+
+* fix: no more false positive matches for Jenkins
+
+## v1.1.1
+
+* docs: sort lists of CI servers in README.md
+* docs: add missing AWS CodeBuild to the docs
+
+## v1.1.0
+
+* feat: add AWS CodeBuild to CI detection ([#2](https://github.com/watson/ci-info/pull/2))
+
+## v1.0.1
+
+* chore: reduce npm package size by using an `.npmignore` file ([#3](https://github.com/watson/ci-info/pull/3))
+
+## v1.0.0
+
+* Initial release
diff --git a/node_modules/ci-info/README.md b/node_modules/ci-info/README.md
index 8e91c3164..a76fd2e16 100644
--- a/node_modules/ci-info/README.md
+++ b/node_modules/ci-info/README.md
@@ -12,7 +12,7 @@ if your CI server isn't properly detected :)
## Installation
-```
+```bash
npm install ci-info --save
```
@@ -38,6 +38,7 @@ Officially supported CI servers:
- [Bitbucket Pipelines](https://bitbucket.org/product/features/pipelines)
- [Buildkite](https://buildkite.com)
- [CircleCI](http://circleci.com)
+- [Cirrus CI](https://cirrus-ci.org)
- [Codeship](https://codeship.com)
- [Drone](https://drone.io)
- [GitLab CI](https://about.gitlab.com/gitlab-ci/)
@@ -46,6 +47,7 @@ Officially supported CI servers:
- [Jenkins CI](https://jenkins-ci.org)
- [Magnum CI](https://magnum-ci.com)
- [Semaphore](https://semaphoreci.com)
+- [Shippable](https://www.shippable.com/)
- [Solano CI](https://www.solanolabs.com/)
- [Strider CD](https://strider-cd.github.io/)
- [TaskCluster](http://docs.taskcluster.net)
@@ -85,6 +87,7 @@ Otherwise `false`.
- `ci.BITBUCKET`
- `ci.BUILDKITE`
- `ci.CIRCLE`
+- `ci.CIRRUS`
- `ci.CODEBUILD`
- `ci.CODESHIP`
- `ci.DRONE`
@@ -93,8 +96,9 @@ Otherwise `false`.
- `ci.HUDSON`
- `ci.JENKINS`
- `ci.MAGNUM`
-- `ci.SOLANO`
- `ci.SEMAPHORE`
+- `ci.SHIPPABLE`
+- `ci.SOLANO`
- `ci.STRIDER`
- `ci.TASKCLUSTER`
- `ci.TEAMCITY`
diff --git a/node_modules/ci-info/package.json b/node_modules/ci-info/package.json
index 7f5c4434a..6c1f1cada 100644
--- a/node_modules/ci-info/package.json
+++ b/node_modules/ci-info/package.json
@@ -1,33 +1,29 @@
{
- "_args": [
- [
- "ci-info@1.3.1",
- "/Users/sibiraj/Documents/cli"
- ]
- ],
- "_from": "ci-info@1.3.1",
- "_id": "ci-info@1.3.1",
+ "_from": "ci-info@1.4.0",
+ "_id": "ci-info@1.4.0",
"_inBundle": false,
- "_integrity": "sha512-l4wK/SFEN8VVTQ9RO1I5yzIL2vw1w6My29qA6Gwaec80QeHxfXbruuUWqn1knyMoJn/X5kav3zVY1TlRHSKeIA==",
+ "_integrity": "sha512-Oqmw2pVfCl8sCL+1QgMywPfdxPJPkC51y4usw0iiE2S9qnEOAqXy8bwl1CpMpnoU39g4iKJTz6QZj+28FvOnjQ==",
"_location": "/ci-info",
"_phantomChildren": {},
"_requested": {
"type": "version",
"registry": true,
- "raw": "ci-info@1.3.1",
+ "raw": "ci-info@1.4.0",
"name": "ci-info",
"escapedName": "ci-info",
- "rawSpec": "1.3.1",
+ "rawSpec": "1.4.0",
"saveSpec": null,
- "fetchSpec": "1.3.1"
+ "fetchSpec": "1.4.0"
},
"_requiredBy": [
+ "#USER",
"/",
"/is-ci"
],
- "_resolved": "https://registry.npmjs.org/ci-info/-/ci-info-1.3.1.tgz",
- "_spec": "1.3.1",
- "_where": ".",
+ "_resolved": "https://registry.npmjs.org/ci-info/-/ci-info-1.4.0.tgz",
+ "_shasum": "4841d53cad49f11b827b648ebde27a6e189b412f",
+ "_spec": "ci-info@1.4.0",
+ "_where": "/Users/zkat/Documents/code/work/npm",
"author": {
"name": "Thomas Watson Steen",
"email": "w@tson.dk",
@@ -36,11 +32,13 @@
"bugs": {
"url": "https://github.com/watson/ci-info/issues"
},
+ "bundleDependencies": false,
"coordinates": [
- 55.777514,
- 12.592202
+ 55.0113914,
+ 14.9747494
],
"dependencies": {},
+ "deprecated": false,
"description": "Get details about the current Continuous Integration environment",
"devDependencies": {
"clear-require": "^1.0.1",
@@ -64,5 +62,5 @@
"scripts": {
"test": "standard && node test.js"
},
- "version": "1.3.1"
+ "version": "1.4.0"
}
diff --git a/node_modules/ci-info/index.js b/node_modules/ci-info/index.js
index 48a298230..74750a7c0 100644
--- a/node_modules/ci-info/index.js
+++ b/node_modules/ci-info/index.js
@@ -9,6 +9,7 @@ var vendors = [
['BITBUCKET', 'Bitbucket Pipelines', 'BITBUCKET_COMMIT'],
['BUILDKITE', 'Buildkite', 'BUILDKITE'],
['CIRCLE', 'CircleCI', 'CIRCLECI'],
+ ['CIRRUS', 'Cirrus CI', 'CIRRUS_CI'],
['CODEBUILD', 'AWS CodeBuild', 'CODEBUILD_BUILD_ARN'],
['CODESHIP', 'Codeship', {CI_NAME: 'codeship'}],
['DRONE', 'Drone', 'DRONE'],
@@ -18,6 +19,7 @@ var vendors = [
['JENKINS', 'Jenkins', 'JENKINS_URL', 'BUILD_ID'],
['MAGNUM', 'Magnum CI', 'MAGNUM'],
['SEMAPHORE', 'Semaphore', 'SEMAPHORE'],
+ ['SHIPPABLE', 'Shippable', 'SHIPPABLE'],
['SOLANO', 'Solano CI', 'TDDIUM'],
['STRIDER', 'Strider CD', 'STRIDER'],
['TASKCLUSTER', 'TaskCluster', 'TASK_ID', 'RUN_ID'],
@@ -27,6 +29,11 @@ var vendors = [
['TRAVIS', 'Travis CI', 'TRAVIS']
]
+// Used for testinging only
+Object.defineProperty(exports, '_vendors', {
+ value: vendors.map(function (v) { return v[0] })
+})
+
exports.name = null
vendors.forEach(function (vendor) {
@@ -43,8 +50,8 @@ vendors.forEach(function (vendor) {
})
exports.isCI = !!(
- env.CI || // Travis CI, CircleCI, Gitlab CI, Appveyor, CodeShip
- env.CONTINUOUS_INTEGRATION || // Travis CI
+ env.CI || // Travis CI, CircleCI, Cirrus CI, Gitlab CI, Appveyor, CodeShip
+ env.CONTINUOUS_INTEGRATION || // Travis CI, Cirrus CI
env.BUILD_NUMBER || // Jenkins, TeamCity
exports.name ||
false